@@ -40,6 +40,7 @@ class PyPacker():
         self.bearer = None
         self.headers = None
         self.api_path = f"{self.hcp_url}/packer/2021-04-30/organizations"
+        self.proj_path = f"{self.api_path}/{self.org_id}/projects/{self.proj_id}"
 
     def authenticate(self):
         """Obtain bearer token"""
@@ -67,7 +68,7 @@ class PyPacker():
         params = {}
         params["location.region.provider"] = provider if provider else 'null'
         params["location.region.region"] = region if region else 'null'
-        url = f"{self.api_path}/{self.org_id}/projects/{self.proj_id}/builds/{build_id}"
+        url = f"{self.proj_path}/builds/{build_id}"
         req = requests.get(url=url, headers=self.headers,\
                            timeout=self.timeout, params=params)
         if req.status_code != 200:
@@ -80,7 +81,7 @@ class PyPacker():
         params = {}
         params["location.region.provider"] = provider if provider else 'null'
         params["location.region.region"] = region if region else 'null'
-        url = f"{self.api_path}/{self.org_id}/projects/{self.proj_id}/builds/{build_id}"
+        url = f"{self.proj_path}/builds/{build_id}"
         req = requests.delete(url=url, headers=self.headers,\
                               timeout=self.timeout, params=params)
         if req.status_code != 200:
@@ -105,11 +106,11 @@ class PyPacker():
 
     def get_bucket(self, bucket=None, bucket_id=None, region=None, provider=None):
         """Get Bucket API call"""
-        params = dict()
+        params = {}
         params["location.region.provider"] = provider
         params["location.region.region"] = region
         params["bucket_id"] = bucket_id
-        url = f"{self.api_path}/{self.org_id}/projects/{self.proj_id}/images/{bucket}"
+        url = f"{self.proj_path}/images/{bucket}"
         req = requests.get(url=url, headers=self.headers,\
                            timeout=self.timeout, params=params)
         if req.status_code != 200:
@@ -132,19 +133,36 @@ class PyPacker():
         print("API route not implemented in this client yet")
         return ""
 
-    def list_channels(self):
+    def list_channels(self, bucket=None, region=None, provider=None):
         """List Channels API Call"""
-        print("API route not implemented in this client yet")
-        return ""
+        params = {}
+        params["location.region.provider"] = provider
+        params["location.region.region"] = region
+        url = f"{self.proj_path}/images/{bucket}/channels"
+        req = requests.get(url=url, headers=self.headers,\
+                           timeout=self.timeout, params=params)
+        if req.status_code != 200:
+            print(f"Error: {req.status_code} {req.reason}")
+            sys.exit(1)
+        return req.json()
+
     def create_channel(self):
         """Create Channel API Call"""
         print("API route not implemented in this client yet")
         return ""
 
-    def get_channel(self):
+    def get_channel(self, bucket=None, channel=None, region=None, provider=None):
         """Get Channel API Call"""
-        print("API route not implemented in this client yet")
-        return ""
+        params = {}
+        params["location.region.provider"] = provider
+        params["location.region.region"] = region
+        url = f"{self.proj_path}/images/{bucket}/channels/{channel}"
+        req = requests.get(url=url, headers=self.headers,\
+                           timeout=self.timeout, params=params)
+        if req.status_code != 200:
+            print(f"Error: {req.status_code} {req.reason}")
+            sys.exit(1)
+        return req.json()
 
     def delete_channel(self):
         """Delete Channel API Call"""
@@ -196,10 +214,18 @@ class PyPacker():
         print("API route not implemented in this client yet")
         return ""
 
-    def get_registry(self):
+    def get_registry(self, region=None, provider=None):
         """Get Registry API Call"""
-        print("API route not implemented in this client yet")
-        return ""
+        params = {}
+        params["location.region.provider"] = provider
+        params["location.region.region"] = region
+        url = f"{self.proj_path}/registry"
+        req = requests.get(url=url, headers=self.headers,\
+                           timeout=self.timeout, params=params)
+        if req.status_code != 200:
+            print(f"Error: {req.status_code} {req.reason}")
+            sys.exit(1)
+        return req.json()
 
     def create_registry(self):
         """Create Registry API Call"""
